@@ -17,7 +17,7 @@ class BaseScheduler(object):
     任务管理和自身的异步任务
     :param DbRedisHelper对象 redis_db: DbRedisHelper对象
     :param BackgroundScheduler对象 scheduler: BackgroundScheduler对象
-    :param str uuid_number: uuid
+    :param str server_name: 服务器名字
     :param str project_name: 项目名字，主要区分不同项目
     :param RedisJobStore对象 redis_job_store: RedisJobStore对象
     """
@@ -26,12 +26,12 @@ class BaseScheduler(object):
             self,
             redis_db: DbRedisHelper,
             scheduler: BackgroundScheduler,
-            uuid_number: str,
+            server_name: str,
             project_name: str,
             redis_job_store: RedisJobStore,
 
     ) -> None:
-        self.uuid_number = uuid_number
+        self.server_name = server_name
         self.project_name = project_name
         self.redis_db = redis_db
         self.scheduler = scheduler
@@ -72,7 +72,7 @@ class BaseScheduler(object):
         检查进程
         :return:
         '''
-        self.redis_db.process_acquire(f'{self.project_name}:node:{self.uuid_number}:{os.getpid()}')
+        self.redis_db.process_acquire(f'{self.project_name}:node:{self.server_name}:{os.getpid()}')
 
     def get_process_list(self) -> list:
         '''
@@ -81,14 +81,14 @@ class BaseScheduler(object):
         '''
         return self.redis_db.get_proces_info()
 
-    def process_check_count(self, process_id: int, check_key: str) -> None:
+    def process_check_count(self, task_node_id: str, check_key: str) -> None:
         '''
         检查任务策略
         :param process_id: 进程pid
         :param check_key:  待检查任务键
         :return:
         '''
-        if process_id not in self.process_id_list:
+        if task_node_id not in self.process_id_list:
             if self.redis_db.acquire(lock_name=check_key):
                 check_value = self.redis_db.from_key_get_value(key_name=check_key)
                 if check_value is None:
@@ -111,7 +111,7 @@ class BaseScheduler(object):
         :return:
         '''
         node_process_id_list = self.get_process_list()
-        self.process_id_list = [int(str(node_id).strip().split(':')[-1]) for node_id in node_process_id_list]
+        self.process_id_list = [node_id.replace('node:', '').strip() for node_id in node_process_id_list]
         # 处理后端操作
         hr = HashRing(nodes=node_process_id_list)
         for backend_key in self.redis_db.get_backend_task():
@@ -132,7 +132,7 @@ class BaseScheduler(object):
         :return:
         '''
         node_process_id_list = self.get_process_list()
-        self.process_id_list = [int(str(node_id).strip().split(':')[-1]) for node_id in node_process_id_list]
+        self.process_id_list = [node_id.replace('node:', '').strip() for node_id in node_process_id_list]
         hr = HashRing(nodes=node_process_id_list)
         # 处理 all_task
         for all_key in self.redis_db.get_all_task():
@@ -146,27 +146,28 @@ class BaseScheduler(object):
                     process_id = int(str(redis_process_node_id).strip().split(':')[-1])
                     # 进程没变化
                     if all_value['is_change'] == 1:
-                        next_key = f'{self.project_name}:{all_value["operation"]}:{self.uuid_number}:{all_value["job_id"]}:{process_id}'
+                        next_key = f'{self.project_name}:{all_value["operation"]}:{self.server_name}:{all_value["job_id"]}:{process_id}'
                         self.redis_db.string_set(key=next_key, value=json.dumps(all_value, ensure_ascii=False))
                         all_value["is_change"] = 0
                         self.redis_db.string_set(key=all_key, value=json.dumps(all_value, ensure_ascii=False))
-                    else:
-                        pass
                 else:
                     # 进程有变化
                     new_process_id = int(str(new_process_node_id).strip().split(':')[-1])
-                    redis_process_id = int(str(redis_process_node_id).strip().split(':')[-1])
-                    delete_key = f'{self.project_name}:delete:{self.uuid_number}:{all_value["job_id"]}:{redis_process_id}'
-                    all_value["details"] = "删除任务"
-                    self.redis_db.string_set(key=delete_key, value=json.dumps(all_value, ensure_ascii=False))
-                    all_value["process_node_id"] = new_process_node_id
                     if all_value['operation'] == 'delete':
-                        # 无需向下一步添加任务
-                        pass
-                    else:
-                        insert_key = f'{self.project_name}:insert:{self.uuid_number}:{all_value["job_id"]}:{new_process_id}'
-                        all_value["details"] = "进程变化，新增任务"
-                        self.redis_db.string_set(key=insert_key, value=json.dumps(all_value, ensure_ascii=False))
+                        # operation = delete 的 无需执行以后操作
+                        all_value["process_node_id"] = new_process_node_id
+                        self.redis_db.string_set(key=all_key, value=json.dumps(all_value, ensure_ascii=False))
+                        continue
+                    redis_process_id = int(str(redis_process_node_id).strip().split(':')[-1])
+                    delete_key = f'{self.project_name}:delete:{self.server_name}:{all_value["job_id"]}:{redis_process_id}'
+                    all_value["details"] = "删除任务"
+                    # 删除旧进程任务
+                    self.redis_db.string_set(key=delete_key, value=json.dumps(all_value, ensure_ascii=False))
+                    # 新进程中添加
+                    all_value["process_node_id"] = new_process_node_id
+                    insert_key = f'{self.project_name}:insert:{self.server_name}:{all_value["job_id"]}:{new_process_id}'
+                    all_value["details"] = "进程变化，新增任务"
+                    self.redis_db.string_set(key=insert_key, value=json.dumps(all_value, ensure_ascii=False))
                     all_value["is_change"] = 0
                     self.redis_db.string_set(key=all_key, value=json.dumps(all_value, ensure_ascii=False))
                 self.redis_db.release(lock_name=all_key)
@@ -183,15 +184,16 @@ class BaseScheduler(object):
             try:
                 process_node_id = insert_value['process_node_id']
                 apscheduler_id = insert_value['job_id']
-                process_id = int(str(process_node_id).strip().split(':')[-1])
-                if os.getpid() == process_id:
+                task_node_id = process_node_id.replace('node:', '')
+                belongs_to_task_node_list = [str(self.project_name), str(self.server_name), str(os.getpid())]
+                belongs_to_task_node_id = ':'.join(belongs_to_task_node_list)
+                if belongs_to_task_node_id == task_node_id:
                     if self.scheduler.get_job(job_id=apscheduler_id):
                         self.scheduler.remove_job(job_id=apscheduler_id)
                     self.scheduler_add_job(**insert_value)
                     self.redis_db.delete_key(lock_name=insert_key)
                 else:
-                    pass
-                    self.process_check_count(process_id=process_id, check_key=insert_key)
+                    self.process_check_count(task_node_id=task_node_id, check_key=insert_key)
             except Exception as e:
                 print(f"check_insert_task 函数 错误 ：{e}")
                 print(traceback.format_exc())
@@ -208,14 +210,16 @@ class BaseScheduler(object):
             try:
                 process_node_id = update_value['process_node_id']
                 apscheduler_id = update_value['job_id']
-                process_id = int(str(process_node_id).strip().split(':')[-1])
-                if os.getpid() == process_id:
+                task_node_id = process_node_id.replace('node:', '')
+                belongs_to_task_node_list = [str(self.project_name), str(self.server_name), str(os.getpid())]
+                belongs_to_task_node_id = ':'.join(belongs_to_task_node_list)
+                if belongs_to_task_node_id == task_node_id:
                     if self.scheduler.get_job(job_id=apscheduler_id):
                         self.scheduler.remove_job(job_id=apscheduler_id)
                     self.scheduler_add_job(**update_value)
                     self.redis_db.delete_key(lock_name=update_key)
                 else:
-                    self.process_check_count(process_id=process_id, check_key=update_key)
+                    self.process_check_count(task_node_id=task_node_id, check_key=update_key)
             except Exception as e:
                 print(f"check_update_task 函数 错误 ：{e}")
                 print(traceback.format_exc())
@@ -233,15 +237,17 @@ class BaseScheduler(object):
             try:
                 process_node_id = delete_value['process_node_id']
                 apscheduler_id = delete_value['job_id']
-                process_id = int(str(process_node_id).strip().split(':')[-1])
-                if os.getpid() == process_id:
+                task_node_id = process_node_id.replace('node:', '')
+                belongs_to_task_node_list = [str(self.project_name), str(self.server_name), str(os.getpid())]
+                belongs_to_task_node_id = ':'.join(belongs_to_task_node_list)
+                if belongs_to_task_node_id == task_node_id:
                     if self.scheduler.get_job(job_id=apscheduler_id):
                         self.scheduler.remove_job(job_id=apscheduler_id)
                     self.redis_db.delete_key(lock_name=delete_key)
                     self.redis_db.delete_key(
                         lock_name=f'{self.project_name}:running_job:{os.getpid()}:{apscheduler_id}')
                 else:
-                    self.process_check_count(process_id=process_id, check_key=delete_key)
+                    self.process_check_count(task_node_id=task_node_id, check_key=delete_key)
             except Exception as e:
                 print(f"check_delete_task 函数 错误 ：{e}")
                 print(traceback.format_exc())
@@ -281,7 +287,7 @@ class BaseScheduler(object):
             lock_value = standard_time()
             self.redis_db.process_acquire(lock_name=key, lock_value=lock_value, expire_time=180)
 
-    def check_redis_jobstores(self):
+    def check_redis_jobstores(self) -> None:
         '''
         异步检查 redis 中 apscheduler 的任务
         :return:
@@ -295,7 +301,7 @@ class BaseScheduler(object):
             job_id = all_value["job_id"]
             job_process_dict[job_id] = process_node_id
         if len(job_process_dict) == 0:
-            return job_process_dict
+            return
         stores_job_task = self.redis_db.get_stores_job_task()
         for stores_job_key in stores_job_task:
             stores_job_run_times_key = stores_job_key.replace('jobs', 'run_times')
@@ -311,23 +317,20 @@ class BaseScheduler(object):
                     pass
                 else:
                     if self.redis_job_store.redis.hexists(stores_job_key, job_id):
-                        pass
                         with self.redis_job_store.redis.pipeline() as pipe:
                             pipe.hdel(stores_job_key, job_id)
                             pipe.execute()
                         with self.redis_job_store.redis.pipeline() as pipe:
                             pipe.zrem(stores_job_run_times_key, job_id)
                             pipe.execute()
-                    continue
 
-    def check_lost_tasks(self):
+    def check_lost_tasks(self) -> None:
         redis_apscheduler_run_time_job_id_set = set()
         for apscheduler_run_time_key in self.redis_db.get_stores_job_run_time_task():
             apscheduler_run_time_byte_list = self.redis_job_store.redis.zrange(
                 apscheduler_run_time_key, 0, 4821384687, withscores=True)
             for job_states_key_byte, run_time__byte_timestamp in apscheduler_run_time_byte_list:
                 redis_apscheduler_run_time_job_id_set.add(job_states_key_byte.decode())
-
         for all_key in self.redis_db.get_all_task():
             all_value = self.redis_db.from_key_get_value(all_key)
             if all_value is None:
