@@ -1,5 +1,6 @@
 from typing import Callable, Dict
 import os
+import uuid
 
 from apscheduler.executors.pool import ThreadPoolExecutor
 from apscheduler.jobstores.redis import RedisJobStore
@@ -32,8 +33,8 @@ class TaskScheduler(object):
     def __init__(self,
                  app: FastAPI,
                  project_name: str,
-                 uuid_number: str,
-                 ssl: bool,
+                 server_name: str = uuid.uuid4().__str__(),
+                 ssl: bool = False,
                  thread_pool_size: int = 10,
                  job_coalesce: bool = True,
                  job_max_instance: int = 1,
@@ -46,13 +47,13 @@ class TaskScheduler(object):
         self.app = app
         self.ssl = ssl
         self.project_name = project_name
-        self.uuid_number = uuid_number
+        self.server_name = server_name
         self.redis_host = redis_host
         self.redis_port = redis_port
         self.username = redis_username
         self.password = redis_password
-        self.jobs_key = self.project_name + ':apscheduler:jobs:' + uuid_number + ":" + str(os.getpid())
-        self.run_times_key = self.project_name + ':apscheduler:run_times:' + uuid_number + ":" + str(os.getpid())
+        self.jobs_key = self.project_name + ':apscheduler:jobs:' + server_name + ":" + str(os.getpid())
+        self.run_times_key = self.project_name + ':apscheduler:run_times:' + server_name + ":" + str(os.getpid())
         self.thread_pool_size = thread_pool_size
         self.job_coalesce = job_coalesce
         self.job_max_instance = job_max_instance
@@ -81,7 +82,7 @@ class TaskScheduler(object):
             project_name=self.project_name,
             redis_db=self.register_redis_db,
             scheduler=self.scheduler,
-            uuid_number=self.uuid_number,
+            server_name=self.server_name,
             redis_job_store=self.redis_job_store
         )
         self.register_async_task()
@@ -212,7 +213,7 @@ class TaskScheduler(object):
     ) -> None:
         self.register_base_scheduler.delete_task(job_id=job_id)
 
-    def get_all_apscheduler_stores_jobs(self):
+    def get_all_apscheduler_stores_jobs(self) -> dict:
         redis_apscheduler_jobs_dict = dict()
         for apscheduler_stores_job_key in self.register_redis_db.get_stores_job_task():
             value_dict = dict()
@@ -232,14 +233,14 @@ class TaskScheduler(object):
             redis_apscheduler_jobs_dict[apscheduler_stores_job_key] = value_dict
         return redis_apscheduler_jobs_dict
 
-    def get_all_redis_tasks(self):
+    def get_all_redis_tasks(self) -> dict:
         all_tasks = dict()
         for all_task_key in self.register_redis_db.connection.keys(pattern=f'{self.project_name}:all:*'):
             value = self.register_redis_db.from_key_get_value(all_task_key)
             all_tasks[all_task_key] = value
         return all_tasks
 
-    def get_all_redis_apscheduler_run_times(self):
+    def get_all_redis_apscheduler_run_times(self) -> dict:
         redis_apscheduler_run_time_dict = dict()
         for apscheduler_run_time_key in self.register_redis_db.get_stores_job_run_time_task():
             value_dict = dict()
@@ -251,20 +252,20 @@ class TaskScheduler(object):
             redis_apscheduler_run_time_dict[apscheduler_run_time_key] = value_dict
         return redis_apscheduler_run_time_dict
 
-    def show_all_redis_key(self):
+    def show_all_redis_key(self) -> list:
         return self.register_redis_db.connection.keys(pattern=f'{self.project_name}:*')
 
-    def show_all_redis_nodes(self):
+    def show_all_redis_nodes(self) -> dict:
         node_dict = dict()
         for node_key in self.register_redis_db.connection.keys(pattern=f'{self.project_name}:node:*'):
             value = self.register_redis_db.connection.get(node_key)
             node_dict[node_key] = value
         return node_dict
 
-    def show_all_redis_tasks(self):
+    def show_all_redis_tasks(self) -> dict:
         return self.get_all_redis_tasks()
 
-    def show_all_scheduler_get_jobs(self):
+    def show_all_scheduler_get_jobs(self) -> dict:
         all_tasks = dict()
         for all_task_key in self.register_redis_db.connection.keys(pattern=f'{self.project_name}:running_job:*'):
             value = dict()
@@ -273,13 +274,13 @@ class TaskScheduler(object):
             all_tasks[all_task_key] = value
         return all_tasks
 
-    def show_all_apscheduler_stores_jobs(self):
+    def show_all_apscheduler_stores_jobs(self) -> dict:
         return self.get_all_apscheduler_stores_jobs()
 
-    def show_all_redis_apscheduler_run_times(self):
+    def show_all_redis_apscheduler_run_times(self) -> dict:
         return self.get_all_redis_apscheduler_run_times()
 
-    def show_all_task_not_in_stores_jobs(self):
+    def show_all_task_not_in_stores_jobs(self) -> dict:
         problem_task = {}
         redis_apscheduler_job_id_list = []
         for redis_apscheduler_jobs_value in self.get_all_apscheduler_stores_jobs().values():
@@ -289,7 +290,7 @@ class TaskScheduler(object):
                 problem_task[all_key] = all_value
         return problem_task
 
-    def show_all_task_not_in_stores_run_times(self):
+    def show_all_task_not_in_stores_run_times(self) -> dict:
         problem_task = {}
         redis_apscheduler_run_time_job_id_list = []
         for redis_apscheduler_job_run_time_value in self.get_all_redis_apscheduler_run_times().values():
@@ -299,7 +300,7 @@ class TaskScheduler(object):
                 problem_task[all_key] = all_value
         return problem_task
 
-    def clear_project_keys(self):
+    def clear_project_keys(self) -> bool:
         for key in self.register_redis_db.connection.keys(pattern=f'{self.project_name}:*'):
             self.register_redis_db.connection.delete(key)
         return True
